## Release 0.8.0

Release date: 2021-03-08

This release contains new features and variety of fixes from 0.7.0.

### Overview

- add statistics from pg_stat_progress_analyze system view
- add statistics from pg_stat_progress_basebackup system view
- add pg_stat_statements WAL usage statistics.
- add pg_stat_statements WAL usage statistics to query report generated by `top` tool.
- add statistics accounting for parallel workers whn profiling queries
 
The above items and other changes are explained in more detail in the sections below.

### New features

1. Support of [pg_stat_progress_analyze](https://www.postgresql.org/docs/current/progress-reporting.html#ANALYZE-PROGRESS-REPORTING) statistics. 
   
Postgres 13 has new progress view which contains statistics about performed ANALYZE commands. Pgcenter now provides 
extended statistics based on pg_stat_progress_analyze and pg_stat_activity views in `top`, `record` and `report` tools.

In the picture below, an example with a bunch of ANALYZE executed and sorted by the scanned amount of data.

![](https://drive.google.com/uc?export=view&id=1sGp9hlzrIb8NJFYwsWxBFBR7mSec7lfL)

2. Support of [pg_stat_progress_basebackup](https://www.postgresql.org/docs/current/progress-reporting.html#BASEBACKUP-PROGRESS-REPORTING) statistics. 
   
Pgcenter now provides extended statistics based on pg_stat_progress_analyze and pg_stat_activity views in `top`, `record`
and `report` tools.

Below an example with backup which started 12 seconds ago and already streamed 12% of 15GB.

![](https://drive.google.com/uc?export=view&id=1qaiAbanKg1TNsIlabMy88VtvCrfQAsKO)

3. Add [pg_stat_statements](https://www.postgresql.org/docs/current/pgstatstatements.html) WAL usage statistics.

Postgres 13 extends functionality of pg_stat_statements with new WAL usage statistics. There are added three new columns: 
wal_records, wal_fpi, wal_bytes. Pgcenter now provides extended statistics based on pg_stat_statements WAL usage in `top`,
`record` and `report` tools. 

WAL usage statistics are organized as additional view:

![](https://drive.google.com/uc?export=view&id=14r4Psj4s5bCYZIvu3JO6bfk5BdVoPAEh)

4. Add [pg_stat_statements](https://www.postgresql.org/docs/current/pgstatstatements.html) WAL usage statistics to query reports generated in top utility

Pgcenter `top` tool provides query reports based on pg_stat_statements. Now reports extended with new WAL usage statistics.

![](https://drive.google.com/uc?export=view&id=1ByGiXGRNsA-61C4CcGO4UgTki5BBSI4l)

5. Tracking statistics of parallel workers when profiling.

Since Postgres 13, [pg_stat_activity](https://www.postgresql.org/docs/current/monitoring-stats.html#MONITORING-PG-STAT-ACTIVITY-VIEW) has a new column - `leader_pid` which reports the PID of parallel worker's leader process.
Using this column `profile` tool can collect statistics about workers. This enabled by default, also a new `-W, --no-workers`
command-line argument has been added to keep old behavior. Note, the feature will not work on Postgres version before 13.

In example below the query profiled in both modes. In the second profile, wait_events are collected including parallel 
workers. 

![](https://drive.google.com/uc?export=view&id=1EGKwnqg_mf_hLV5uD35rSe7itPFFo8ub)

### Fixes
- fixed panic of `top` when executing it using Docker containers. See [#87](https://github.com/lesovsky/pgcenter/issues/87) for details.

- fixed connection problems related to using simple protocol.

  Simple protocol is used for compatibility with Pgbouncer. At the same time, using simple protocol adds some implicit 
  limitations. Two new limitations have been found - connection should be established with `standard_conforming_strings=on`
  and `client_encoding=UTF8` if such parameters are different in server configuration. It seems, there are could be another
  similar side effects of using simple protocol.

- fixed detecting when working with local or remote Postgres.

  Pgcenter can show local system statistics, but it might be unneeded when working with remote Postgres. In such case Pgcenter
  have to detect is Postgres local or remote. This was broken in 0.7.0, now it is fixed.

### Other

- Use `alpine` as a base image instead of `scratch` when building Docker images. Pgcenter has external dependency, `getconf`
  utility for detecting CLK_TCK and proper system statistics calculation. The `alpine` image has `getconf`.  

- Updated go version up to 1.16. 

- Made internal code refactoring to improve unit-testing coverage. Some functionality is quite hard to test and for increasing
  test coverage, the code is re-organized, and some re-design has been made related to internal types and functions.

- Add templates for issues and feature requests. When creating an issue, it is recommended to use the special template. 
  This helps to explain the issue in details and avoids requesting extra info about the discovered problem. Also feature
  request template has been added which helps to provide more information about the requested feature.

- New 'release notes' section has been created in hope to provide more useful and detailed info about releases.