## Release 0.9.0

Release date: 2021-06-15

This release contains new features and variety of fixes from 0.8.0.

### Overview

Pgcenter 0.9.0 contains new features and enhancements, including:
- add session statistics from `pg_stat_database` (Postgres 14)
- add WAL usage statistics from `pg_stat_wal` (Postgres 14)
- add progress statistics about running COPY commands from `pg_stat_progress_copy` (Postgres 14)
- add filesystem stats for `top` utility
- extend statistics about tables sizes
- add support for millisecond resolution for `record` and `report` utilities
- add naming convention for columns names

The above items and other changes are explained in more detail in the sections below.

### New features

1. Support of session statistics from [pg_stat_database](https://www.postgresql.org/docs/devel/monitoring-stats.html#MONITORING-PG-STAT-DATABASE-VIEW) view.

Upcoming Postgres 14 has new session statistics available in `pg_stat_database` view. It includes information about how 
much time were spent by sessions, and how many sessions were established and terminated due to various reasons.
Pgcenter now provides databases statistics as separate views: general and sessions (like statements or progress statistics).
For `top` utility a new shortcut has been introduced: `G` - it opens "database statistics" menu. Existing `g` shortcut now is
working as switcher between databases statistics.

In the picture below, an example of database sessions statistics.

![](https://drive.google.com/uc?export=view&id=14dKVMOLSMatotNINCbO8-hVcox-pnWVR)

2. Support of WAL usage statistics from [pg_stat_wal](https://www.postgresql.org/docs/devel/monitoring-stats.html#MONITORING-PG-STAT-WAL-VIEW) view.

Upcoming Postgres 14 has new WAL usage statistics available in `pg_stat_wal`. This view contains a single-row about how much WAL
is generated during server lifetime. Pgcenter now provides statistics based on `pg_stat_wal` in `top`, `record` and `report` tools.

In the picture below, an example of WAL usage statistics.

![](https://drive.google.com/uc?export=view&id=17Yxmq35fh7fmhy5dtYsHG4M7LHief2W-)

3. Support of progress statistics about running COPY commands from [pg_stat_progress_copy](https://www.postgresql.org/docs/devel/progress-reporting.html#COPY-PROGRESS-REPORTING) view.

Upcoming Postgres 14 has new "progress" statistics about running `COPY` in `pg_stat_progress_copy` view. This view is useful for
tracking COPY commands which usually executed during import and export data (via `pg_dump` or `copy` utilities). Pgcenter now
provides statistics based on `pg_stat_progress_copy` in `top`, `record` and `report` tools.

In the picture below, an example of COPY progress statistics.

![](https://drive.google.com/uc?export=view&id=1djbdidLR_0W1g4KSdc8maXkIjw0mbxLT)

4. Add extra statistics about filesystems usage for `top` utility.

`top` utility provides "extra" statistics (is not displayed by default), about block devices and network interfaces. New statistics
about mounted filesystems is available now. There is information about total size of filesystem, used and free space and inodes.
New shortcut has been added, `F` - toggles (on/off) displaying of filesystem usage stats.

In the picture below, an example of screen with enabled filesystem statistics.

![](https://drive.google.com/uc?export=view&id=1ORGBTNklCVidgsozLg6dExHGqalqul-F)

5. Extend statistics about tables sizes.
   
New values are added for tables sizes statistics: size of tables metadata (VM, FSM, init forks) and TOASTs. This gives more
detailed overview of how disk space are utilized by particular table.

In the picture below, an example of statistics with new values.

![](https://drive.google.com/uc?export=view&id=1Nx5Dp4nahOuSqVeSX8ySU7IFyE7PKOVT)

6. Support of millisecond resolution in `record` and `report` utilities.

Earlier versions of `record` tool was designed to record statistics with 1 second (and higher) interval. Now it is possible
to record statistics with millisecond resolution. This might be useful for recording statistics more frequently, especially
during short-term periods (e.g. benchmarks). The `report` tool also supports sub-second resolution and prints this information
when do report.

7. Add naming convention for statistics columns names.

Common naming rules are introduced for all column names. The goal is to make name of columns clear for the user. All column
names have been reviewed and renamed if it was required. 

### Fixes
- fix crash of `top` utility when selecting an item "outside" of menus.

- fix rare bug of `top` utility when program crashes on switching between stats views.

- fix errors related to wrong query templating when displaying tables statistics.

- fix issue when pg_stat_statements cannot be found due to installed on schema other than 'public'.

- fix error occurred when `record` and `top` utilities attempts collecting stats which is not supported by Postgres.

### Other
- Show program version info in the help screen of `top` utility.

- When install pgcenter from packages, use `/usr/bin` system path instead of `/usr/local/bin`.

- Add `apk` package format when building packages on release.

- Add support of `pg_stat_database.numbackends` field.

- Remove `--rate` flag of `report` utility.